<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class CMP_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		define('CMP_PLUGIN_DIR', plugin_dir_url(__FILE__));
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
	    wp_enqueue_style('wp-color-picker');
		wp_enqueue_style( 'cmp_fonts_css', plugin_dir_url( __FILE__ ) . 'css/fonts.css ', array(), $this->version, 'all' );  
		wp_enqueue_style( 'cmp_jquery_ui_css', plugin_dir_url( __FILE__ ) . 'css/jquery-ui.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'cmp_datatable_css', plugin_dir_url( __FILE__ ) . 'css/jquery.dataTables.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'font_awesome_css', plugin_dir_url( __FILE__ ) . 'css/font-awesome.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cmp-admin.css', array('wp-color-picker'), $this->version, 'all' );
		wp_enqueue_style( 'cmp_style_css', plugin_dir_url( __FILE__ ) . 'css/style.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_media();
		wp_enqueue_script( 'cmp_jquery_ui_js', plugin_dir_url( __FILE__ ) . 'js/jquery-ui.min.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( 'cmp_datatable_js', plugin_dir_url( __FILE__ ) . 'js/jquery.dataTables.min.js', array( 'jquery' ), $this->version, false ); 
		//wp_enqueue_script( 'cmp_datatable255_js', plugin_dir_url( __FILE__ ) . 'js/TableTools.min.js', array( 'jquery' ), $this->version, true ); 
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cmp-admin.js', array( 'jquery','wp-color-picker' ), $this->version, false );
		wp_localize_script( $this->plugin_name,'ajaxobject', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );
		wp_localize_script($this->plugin_name,'image_urls', array( 'form_request_url' => CMP_PLUGIN_DIR."partials/generatecsv.php",) ); 
		wp_localize_script($this->plugin_name,'image_url', array( 'form__url' => CMP_PLUGIN_DIR,) ); 
	}
	
	public function cmp_admin_menu(){
		add_menu_page( 
			__( 'CF7 Mailchimp', 'cf7-mailchimp-addon' ),
			__( 'CF7 Mailchimp', 'cf7-mailchimp-addon' ),
			'manage_options',
			'cmp_dashboard',
			array( $this, 'settings' ),
			plugin_dir_url( __FILE__ ) . 'images/cf7menuicon.png', 
			999
		); 
		add_submenu_page(
	        'cmp_dashboard',
	        'Dashboard',
	        'Dashboard',
	        'manage_options',
	        'cmp_dashboard'
	    );
		add_submenu_page(
	        'cmp_dashboard',
	        'Settings',
	        'Settings',
	        'manage_options',
	        'cmp_settings',
	        array( $this, 'settings' )
	    );
		
		$setting_array = get_option('cmp_subscriber_settings');
		$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
		if(isset($setting_array['Mailchimp']['api_key']) and $setting_array['Mailchimp']['api_key'] != "" and $status =="connect" ){
			if(post_type_exists( 'wpcf7_contact_form' )){
				add_submenu_page(
					'cmp_dashboard',
					'Data Log',
					'Data Log',
					'manage_options',
					'cmp_data_log',
					array( $this, 'settings' )
				);
			}
			add_submenu_page(
				'cmp_dashboard',
				'Broadcast Messages',
				'Broadcast Messages',
				'manage_options',
				'cmp_boardcast_message',
				array( $this, 'settings' )
			);
			add_submenu_page(
				'cmp_dashboard',
				'List Manager',
				'List Manager',
				'manage_options',
				'cmp_list_manager',
				array( $this, 'settings' )
			);
			add_submenu_page(
				'cmp_dashboard',
				'Custom Template',
				'Custom Template',
				'manage_options',
				'cmp_custom_template',
				array( $this, 'settings' )
			);
		}
	}
	
	public function settings(){
		global $wpdb; 

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_dashboard'){
			require_once plugin_dir_path( __FILE__ ) . 'partials/dashboard.php';  
		}

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_settings'){
			$setting_array = get_option('cmp_subscriber_settings');
			$api =  $setting_array['Mailchimp']['api_key'];
			$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
			/* if(get_option('cmp_subscriber_status')){
				$status=get_option('cmp_subscriber_status');
			}else{
				$status="disconnect";
			} */
			require_once CMP_PATH . 'includes/subscriber.php';
			require_once plugin_dir_path( __FILE__ ) . 'partials/settings.php';
		}

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_data_log'){
			$setting_array = get_option('cmp_subscriber_settings');
			$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
			require_once plugin_dir_path( __FILE__ ) . 'partials/data_log.php';
		}

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_boardcast_message'){
			$setting_array = get_option('cmp_subscriber_settings');
			$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
			require_once plugin_dir_path( __FILE__ ) . 'partials/boardcast_message.php';
		}

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_list_manager'){
		    $setting_array = get_option('cmp_subscriber_settings');
			$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
		    require_once plugin_dir_path( __FILE__ ) . 'partials/list_manager.php';
		}

		if(isset($_GET['page']) && $_GET['page'] == 'cmp_custom_template'){
			$setting_array = get_option('cmp_subscriber_settings');
			$api =  $setting_array['Mailchimp']['api_key'];
			$status=get_option('cmp_subscriber_status')?get_option('cmp_subscriber_status'):'';
			require_once CMP_PATH . 'includes/subscriber.php';
			require_once plugin_dir_path( __FILE__ ) . 'partials/templates.php';   
		}
	}
	
	public function save_subscriber_setting(){

		require_once CMP_PATH . 'includes/subscriber.php';

		$data = get_option('cmp_subscriber_settings');
		
		if(empty($_POST['responder'])){			
			echo json_encode(array( 'error' => 'Error occur may be something wrong.'));
			return;
		}
		
		$data[$_POST['responder']] = $_POST['apikey'];
		
		if(empty($_POST['apikey'])){
			update_option('cmp_subscriber_settings', $data);
			die();
		}
		
		 if(!empty($data['Mailchimp']['api_key'])){
			 $objlist = new cmp_subscriber();
			 $list = $objlist->switch_responder($_POST['apikey'], 'getList', $_POST['responder']);
			 $res = $_POST['responder'];
			 if( $res!='Aweber'){
					  update_option('cmp_subscriber_settings', $data);
			 }
			 update_option('cmp_subscriber_status',"connect");
			 echo json_encode(array('success'=>true));
		  }else{
			   echo json_encode(array('error'=>'An error occurred while getting your list.'));
			   update_option('cmp_subscriber_status',"disconnect");
		  }
		
		die();
	}

	public function add_new_form_setting(){
		if(isset($_POST['cmp_add_new_form'])){
			$form_id = $_POST['cmp_add_new_form'];
			$list_id = $_POST['cmp_list_id'];
			$result= $this->add_new_formfn($form_id , $list_id );
			echo $result;
			die();
		}
		
		if(isset($_POST['cmp_add_cf7_list'])){
			global $wpdb;
			$method = $_POST['cmp_edit_content'];
			$list_id = $_POST['cmp_add_cf7_list'];
			$form_id = $_POST['cmp_add_cf7_form'];
			$field_selected = json_encode($_POST['cmp_add_cf7_selected']);
			$field_disabled =json_encode($_POST['cmp_add_cf7_disabled']);
			$mailchimp_list = json_encode($_POST['cmp_add_cf7_mailchimp']);  

			$wpdb->get_results("SELECT * FROM ".$wpdb->prefix."cmp_form_data WHERE list_id = '".$list_id."' AND form_id = '".$form_id."' "); 
			if($wpdb->num_rows == 0){
				$data =array(
					'list_id' => $list_id,
					'form_id' => $form_id,
					'mailchimp_list' => $mailchimp_list, 
					'field_selected' => $field_selected,
					'field_disabled' => $field_disabled,
				); 
				$result = $wpdb->insert($wpdb->prefix . 'cmp_form_data' , $data);  
				
			}else if($method == "edit"){
				$data = array( 'mailchimp_list' => $mailchimp_list,
					'field_selected' => $field_selected,
					'field_disabled' => $field_disabled, 
				);
                $where = array('form_id' => $form_id , 'form_id' => $form_id,  ); 
                $result = $wpdb->update($wpdb->prefix."cmp_form_data", $data, $where); 
			}

			if($result){
				echo "Save Succrssfufully";
			}else{
				echo "fail";
			} 
			die();
		}
		
		if(isset($_POST['cmp_delete_form'])){
			global $wpdb;
			$form_id =  $_POST['cmp_delete_form'];
			$list_id = $_POST['cmp_delete_form_list_id'];
			$result = $wpdb->delete($wpdb->prefix."cmp_form_data", array('form_id' => $form_id , 'list_id' => $list_id )); 
			if($result){
				echo "success";
			}else{
				echo "fail";
			}
			die();
		}
		
		if(isset($_POST['cmp_edit_form'])){
			global $wpdb;
			$form_id =  $_POST['cmp_edit_form'];
			$list_id = $_POST['cmp_edit_form_list_id'];
			$method = $_POST['cmp_method'];
			$result_array =array();
			$result =$wpdb->get_results("SELECT * FROM ".$wpdb->prefix."cmp_form_data WHERE list_id = '".$list_id."' AND form_id = '".$form_id."' "); 
			if($wpdb->num_rows > 0){
				$list_id = $result[0]->list_id;
				$form_id = $result[0]->form_id;
				$result_array['selected'] = json_decode($result[0]->field_selected);
				$result_array['mailchimp'] = json_decode($result[0]->mailchimp_list);
				$result_array['disabled'] = json_decode($result[0]->field_disabled);
				$result= $this->add_new_formfn($form_id , $list_id, $method , $result_array);
			    echo $result;
				//echo json_encode($result_array);
			}
			die();
		}
		
	}
	
	public function save_templete_setting(){
		if(isset($_POST['cmp_temp_form'])){
			global $wpdb;
			$list_id = $_POST['cmp_temp_form'];
			$template = $_POST['cmp_temp_template'];
			$data_temp = json_encode($_POST['cmp_temp_data']); 
			$shortcode = $_POST['cmp_temp_shortcode'];
			$result = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix."cmp_template_data WHERE list_id = '".$list_id."' and template_id = '".$template."'  ");
			if($wpdb->num_rows>0){
				$data =array(
					'data' => $data_temp,
				); 
				$where = array('list_id' => $list_id , 'template_id' => $template,  ); 
				$result1 = $wpdb->update($wpdb->prefix."cmp_template_data", $data, $where);
			}else{
				$data =array(
					'list_id' => $list_id,
					'template_id' => $template,
					'data' => $data_temp,
				); 
				//echo $list_id.",".$template.",".$data;   
				$result1 = $wpdb->insert($wpdb->prefix . 'cmp_template_data' , $data);  
			}
			if($result1){
				echo "Save Successfully";
			}else{
				echo "Form not submit successfully"; 
			}
			die();	 
		}	 
	}
	
	public function save_templete_select_list(){
		global $wpdb;
		if(isset($_POST['cmp_temp_list'])){  
			$list_id = $_POST['cmp_temp_list'];
			$template = $_POST['cmp_temp_temp'];
			$result = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix."cmp_template_data WHERE list_id = '".$list_id."' and template_id = '".$template."'  ");
			if($wpdb->num_rows>0){
				$data = $result[0]->data;
				echo($data);
			}else{
				echo "fail";
			} 
			die();
		} 
	}
	
	public function save_templete_reset_list(){
		global $wpdb;
		if(isset($_POST['cmp_reset_list'])){  
			$list_id = $_POST['cmp_reset_list'];
			$template = $_POST['cmp_reset_temp'];
			$result = $wpdb->delete($wpdb->prefix."cmp_template_data", array('list_id' => $list_id , 'template_id' => $template ));   
			if($result){
				echo "success"; 
			}else{
				echo "fail";
			}
			die();
		}
	}
	
	public function add_new_formfn($form_id , $list_id , $method = '' , $result_array = array() ){
		$api_key =  get_option('cmp_subscriber_settings')['Mailchimp']['api_key']; 
		$mcapi_conn = new Mailchimp($api_key); 
		$retval = $mcapi_conn->get("lists/$list_id/merge-fields");
		
		$div="";  
		if(!empty($form_id)){
			$div .="<div style='display:none;'>".do_shortcode("[contact-form-7 id='".$form_id ."' ]")."</div>";
			$div .="<div style='display:none;' id='cmp_add_new_method' >".$method."</div>";
			$div .='<div class="cmp_field_boxes cmp_field_boxes_1">
							<label>Mailchimp Fields</label>
							<ul id="cmp_add_mailchimp_ul">';
							$div .='<li> EMAIL<input type="hidden" name="cmp_form_fieldselect[]" value="EMAIL"  class="cmp_draggable_input"  ></li>';
					  foreach( $retval as $list ){
						   if($list['tag'] != 'EMAIL'){ 
								$div .='<li> '.$list['tag'].'<input type="hidden" name="cmp_form_fieldselect[]" value="'.$list['tag'].'"  class="cmp_draggable_input"  ></li>'; 
						   }
						}
			$div .= '</ul>
				   </div>';
				   
			if($method == "edit"){
				$div .='<div class="cmp_field_boxes cmp_field_boxes_2">
					<label>CF7 Enable Fields</label>
					<ul id="cmp_add_new_enable_ul" class="cmp_draggable">';
				/* foreach($result_array['selected'] as $value){
					if($value == "your-email"){
						$div .='<li class="ui-state-disabled"><label>'.$value.'</label><input type="hidden" name="cmp_form_fieldselect[]" value="'.$value.'" class="cmp_draggable_input" /></li>';
					}else{
						$div .='<li><label>'.$value.'</label><input type="hidden" name="cmp_form_fieldselect[]" value="'.$value.'" class="cmp_draggable_input" /></li>'; 
					}
				}  */
				$div .='</ul>
					</div>';

				$div .='<div class="cmp_field_boxes cmp_field_boxes_3">
					<span>CF7 Disable  Fields</span>
					<ul id="cmp_add_new_disable_ul" class="cmp_draggable">';
				/* foreach($result_array['disabled'] as $value){
					$div .='<li><label>'.$value.'</label><input type="hidden" name="cmp_form_fieldselect[]" value="'.$value.'" class="cmp_draggable_input" /></li>'; 
				} */
				$div .='</ul>
				</div>';

				$div .="<script>
					jQuery(document).ready(function($){	
						var cffield_arr = ".json_encode($result_array['selected']).";
						var cffield_arr_dis = ".json_encode($result_array['disabled']).";
						//console.log(cffield_arr);  
						var res_arr =  new Array();
						$('.wpcf7 form :input').each(function(index, elm){
							if($(elm).attr('type')!='hidden' && $(elm).attr('type') !='submit'){
			
								if(cffield_arr !=''){ 
									var form_field = $(elm).attr('name');  
									//console.log(jQuery.inArray( form_field, cffield_arr ));
									if(jQuery.inArray( form_field, cffield_arr ) !== -1    ){
										
										res_arr[jQuery.inArray( form_field, cffield_arr ) ] = form_field;
										
									}else if(jQuery.inArray( form_field, cffield_arr_dis ) !== -1 ){
										var lab = ' '+form_field+'<br>';
										var check_fields = $('<li>').html(lab).prepend($('<input/>').attr({ type: 'hidden', value:form_field , name:'cmp_form_fieldselect[]'}).addClass('cmp_draggable_input'));
										$('#cmp_add_new_disable_ul').append(check_fields);
									}else{
										var lab = ' '+form_field+'<br>';
										var check_fields = $('<li>').html(lab).prepend($('<input/>').attr({ type: 'hidden', value:form_field , name:'cmp_form_fieldselect[]'}).addClass('cmp_draggable_input'));
										$('#cmp_add_new_disable_ul').append(check_fields);
									}
								}else{
								var form_field = $(elm).attr('name');  
								var lab = ' '+form_field+'<br>';
								//if(form_field == 'your-email'){
								//}else{ 
									var check_fields = $('<li>').html(lab).prepend($('<input/>').attr({ type: 'hidden', value:form_field , name:'cmp_form_fieldselect[]'}).addClass('cmp_draggable_input'));
									$('#cmp_add_new_enable_ul').append(check_fields);
								//}
								}
								
							} 
							
						}); 
						console.log(res_arr);
						jQuery.each( res_arr, function( i, val ) {  
							
						if(val != undefined){	
							var lab = ' '+val+'<br>';
							var check_fields = $('<li>').html(lab).prepend($('<input/>').attr({ type: 'hidden', value:val , name:'cmp_form_fieldselect[]'}).addClass('cmp_draggable_input'));
							$('#cmp_add_new_enable_ul').append(check_fields);
						}
						});
						jQuery( '#cmp_add_new_enable_ul , #cmp_add_new_disable_ul' ).sortable({
							connectWith: '.cmp_draggable',
							items: 'li:not(.ui-state-disabled)',
						}).disableSelection();
					});
				</script>";
			}else{
				$div .='<div class="cmp_field_boxes cmp_field_boxes_2">
						<label>CF7 Enable Fields</label>
						<ul id="cmp_add_new_enable_ul" class="cmp_draggable">';
					
				$div .='</ul>
					</div>';	   
			
				$div .='<div class="cmp_field_boxes cmp_field_boxes_3">
						<span>CF7 Disable  Fields</span>
						<ul id="cmp_add_new_disable_ul" class="cmp_draggable">
						</ul>
					</div>';
				
				$div .="<script> 
					jQuery(document).ready(function($){
						$('.wpcf7 form :input').each(function(index, elm){
							if($(elm).attr('type')!='hidden' && $(elm).attr('type') !='submit'){
								var form_field = $(elm).attr('name');  
								var lab = ' '+form_field+'<br>';
								
									var check_fields = $('<li>').html(lab).prepend($('<input/>').attr({ type: 'hidden', value:form_field , name:'cmp_form_fieldselect[]'}).addClass('cmp_draggable_input'));
									$('#cmp_add_new_enable_ul').append(check_fields);
								
							}				
						});

						jQuery( '#cmp_add_new_enable_ul , #cmp_add_new_disable_ul' ).sortable({
							connectWith: '.cmp_draggable',
							items: 'li:not(.ui-state-disabled)',
						}).disableSelection();	 
					});
				</script>";
			}
		}
		return $div;
		
	}
	 
}